@@ -35,9 +35,11 @@ import (
 var (
 	DirPrefix string
 	DepCwd    string
+
+	ErrBadRecFormat = errors.New("invalid format of .rec")
 )
 
-func recfileWrite(fdDep *os.File, fields ...recfile.Field) error {
+func recfileWrite(fdDep io.StringWriter, fields ...recfile.Field) error {
 	w := recfile.NewWriter(fdDep)
 	if _, err := w.RecordStart(); err != nil {
 		return err
@@ -49,7 +51,7 @@ func recfileWrite(fdDep *os.File, fields ...recfile.Field) error {
 }
 
 func ifcreate(fdDep *os.File, tgt string) error {
-	trace(CDebug, "ifcreate: %s <- %s", fdDep.Name(), tgt)
+	tracef(CDebug, "ifcreate: %s <- %s", fdDep.Name(), tgt)
 	return recfileWrite(
 		fdDep,
 		recfile.Field{Name: "Type", Value: DepTypeIfcreate},
@@ -58,17 +60,17 @@ func ifcreate(fdDep *os.File, tgt string) error {
 }
 
 func always(fdDep *os.File) error {
-	trace(CDebug, "always: %s", fdDep.Name())
+	tracef(CDebug, "always: %s", fdDep.Name())
 	return recfileWrite(fdDep, recfile.Field{Name: "Type", Value: DepTypeAlways})
 }
 
 func stamp(fdDep, src *os.File) error {
 	var hsh string
-	hsh, err := fileHash(os.Stdin)
+	hsh, err := fileHash(src)
 	if err != nil {
 		return err
 	}
-	trace(CDebug, "stamp: %s <- %s", fdDep.Name(), hsh)
+	tracef(CDebug, "stamp: %s <- %s", fdDep.Name(), hsh)
 	return recfileWrite(
 		fdDep,
 		recfile.Field{Name: "Type", Value: DepTypeStamp},
@@ -84,8 +86,8 @@ func fileHash(fd *os.File) (string, error) {
 	return hex.EncodeToString(h.Sum(nil)), nil
 }
 
-func writeDep(fdDep *os.File, cwd, tgt string) error {
-	trace(CDebug, "ifchange: %s <- %s", fdDep.Name(), tgt)
+func depWrite(fdDep *os.File, cwd, tgt string) error {
+	tracef(CDebug, "ifchange: %s <- %s", fdDep.Name(), tgt)
 	fd, err := os.Open(path.Join(cwd, tgt))
 	if err != nil {
 		return err
@@ -115,9 +117,9 @@ func writeDep(fdDep *os.File, cwd, tgt string) error {
 	return recfileWrite(fdDep, fields...)
 }
 
-func writeDeps(fdDep *os.File, tgts []string) (err error) {
+func depsWrite(fdDep *os.File, tgts []string) error {
 	if fdDep == nil {
-		trace(CDebug, "no opened fdDep: %s", tgts)
+		tracef(CDebug, "no opened fdDep: %s", tgts)
 		return nil
 	}
 	for _, tgt := range tgts {
@@ -135,9 +137,9 @@ func writeDeps(fdDep *os.File, tgts []string) (err error) {
 			panic(err)
 		}
 		if _, errStat := os.Stat(tgt); errStat == nil {
-			err = writeDep(fdDep, tgtDir, tgtRel)
+			err = depWrite(fdDep, tgtDir, tgtRel)
 		} else {
-			trace(CDebug, "ifchange: %s <- %s (non-existing)", fdDep.Name(), tgtRel)
+			tracef(CDebug, "ifchange: %s <- %s (non-existing)", fdDep.Name(), tgtRel)
 			fields := []recfile.Field{
 				{Name: "Type", Value: DepTypeIfchange},
 				{Name: "Target", Value: tgtRel},
@@ -146,8 +148,11 @@ func writeDeps(fdDep *os.File, tgts []string) (err error) {
 			fields = append(fields, inodeDummy.RecfileFields()...)
 			err = recfileWrite(fdDep, fields...)
 		}
+		if err != nil {
+			return err
+		}
 	}
-	return
+	return nil
 }
 
 type DepInfo struct {
@@ -158,22 +163,22 @@ type DepInfo struct {
 	ifchanges []map[string]string
 }
 
-func depRead(fdDep *os.File) (*DepInfo, error) {
+func depRead(fdDep io.Reader) (*DepInfo, error) {
 	r := recfile.NewReader(fdDep)
 	m, err := r.NextMap()
 	if err != nil {
 		return nil, err
 	}
 	depInfo := DepInfo{}
-	if b := m["Build"]; b == "" {
+	b := m["Build"]
+	if b == "" {
 		return nil, errors.New(".rec missing Build:")
-	} else {
-		depInfo.build = b
 	}
+	depInfo.build = b
 	for {
 		m, err := r.NextMap()
 		if err != nil {
-			if err == io.EOF {
+			if errors.Is(err, io.EOF) {
 				break
 			}
 			return nil, err
@@ -184,7 +189,7 @@ func depRead(fdDep *os.File) (*DepInfo, error) {
 		case DepTypeIfcreate:
 			dep := m["Target"]
 			if dep == "" {
-				return nil, errors.New("invalid format of .rec")
+				return nil, ErrBadRecFormat
 			}
 			depInfo.ifcreates = append(depInfo.ifcreates, dep)
 		case DepTypeIfchange:
@@ -193,11 +198,11 @@ func depRead(fdDep *os.File) (*DepInfo, error) {
 		case DepTypeStamp:
 			hsh := m["Hash"]
 			if hsh == "" {
-				return nil, errors.New("invalid format of .rec")
+				return nil, ErrBadRecFormat
 			}
 			depInfo.stamp = hsh
 		default:
-			return nil, errors.New("invalid format of .rec")
+			return nil, ErrBadRecFormat
 		}
 	}
 	return &depInfo, nil
