@@ -60,7 +60,7 @@ func findDo(fdDep *os.File, cwd, tgt string) (string, int, error) {
 			doFile = strings.Join(append(
 				[]string{"default"}, append(exts, "do")...,
 			), ".")
-			if len(levels) > 0 || doFile != doFileOrig {
+			if len(levels) > 0 || (doFile != doFileOrig && doFile != tgt) {
 				exists, err = existsDo(fdDep, cwd, path.Join(updir, doFile))
 				if err != nil {
 					return "", 0, err
@@ -72,7 +72,7 @@ func findDo(fdDep *os.File, cwd, tgt string) (string, int, error) {
 			exts = exts[1:]
 		}
 		doFile = "default.do"
-		if len(levels) > 0 || doFile != doFileOrig {
+		if len(levels) > 0 || (doFile != doFileOrig && doFile != tgt) {
 			exists, err = existsDo(fdDep, cwd, path.Join(updir, doFile))
 			if err != nil {
 				return "", 0, err
