@@ -138,10 +138,6 @@ func main() {
 		log.Fatalln(err)
 	}
 
-	NoColor = os.Getenv(EnvNoColor) != ""
-	NoSync = os.Getenv(EnvNoSync) == "1"
-	InodeTrust = os.Getenv(EnvInodeNoTrust) == ""
-
 	TopDir = os.Getenv(EnvTopDir)
 	if TopDir == "" {
 		TopDir = "/"
@@ -198,6 +194,19 @@ func main() {
 	} else if flagTrace != nil {
 		traced = *flagTrace
 	}
+	NoColor = os.Getenv(EnvNoColor) != ""
+	NoSync = os.Getenv(EnvNoSync) == "1"
+	switch s := os.Getenv(EnvInodeTrust); s {
+	case "none":
+		InodeTrust = InodeTrustNone
+	case "", "ctime":
+		InodeTrust = InodeTrustCtime
+	case "mtime":
+		InodeTrust = InodeTrustMtime
+	default:
+		log.Fatalln("unknown", EnvInodeTrust, "value")
+	}
+	tracef(CDebug, "inode-trust: %s", InodeTrust)
 
 	// Those are internal envs
 	FdOODTgts, err = ioutil.TempFile("", "ood-tgts")
