@@ -171,7 +171,7 @@ func isOOD(cwd, tgtOrig string, level int, seen map[string]struct{}) (bool, erro
 			ood = true
 			goto Done
 		}
-		if InodeTrust && inode.Equals(theirInode) {
+		if InodeTrust != InodeTrustNone && inode.Equals(theirInode) {
 			tracef(CDebug, "ood: %s%s -> %s: same inode", indent, tgtOrig, dep)
 		} else {
 			tracef(CDebug, "ood: %s%s -> %s: inode differs", indent, tgtOrig, dep)
