@@ -616,10 +616,9 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 
 		// Was $1 touched?
 		if fd, err := os.Open(path.Join(cwdOrig, tgt)); err == nil {
-			errTouched := Err1WasTouched
 			if inodePrev == nil {
 				fd.Close()
-				runErr.Err = errTouched
+				runErr.Err = Err1WasTouched
 				errs <- runErr
 				return
 			}
@@ -631,7 +630,7 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 				return
 			}
 			if !inode.Equals(inodePrev) {
-				runErr.Err = errTouched
+				runErr.Err = Err1WasTouched
 				errs <- runErr
 				return
 			}
